<?php
/**
 * The admin-specific functionality of the plugin.
 * 
 * @link       seenthis.co
 * @since      1.1.0
 *
 * @package    Greenweb
 * @subpackage Greenweb/admin
 * @author     Seenthis
 */
class Greenweb_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.1.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.1.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.1.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.1.0
	 */
	public function admin_enqueue_styles($hook) {
		if (!strpos($hook, 'admin-display.php')) {
			return;
		}
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/greenweb-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.1.0
	 */
	public function admin_enqueue_scripts($hook) {
		if (!strpos($hook, 'admin-display.php')) {
			return;
		}
			wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/greenweb-admin.js', array( 'jquery' ), $this->version, false );

	}

	/**
	 * Register the admin page.
	 */
	public function set_admin_menu() {
		add_menu_page( $this->plugin_name, greenweb_globals\pluginName, 'manage_options', greenweb_globals\rootFolder.'/admin/partials/admin-display.php');
	}
}
