<?php
require 'greenweb_globals.php';
$greenweb_globals = new greenweb_globals\greenweb_settings();
/**
 * The plugin bootstrap file
 *
 * @link              seenthis.co
 * @since             1.1.0
 * @package           Sitestream
 *
 * @wordpress-plugin
 * Plugin Name:       Sitestream
 * Plugin URI:        seenthis.co
 * Description:       Sitestream reduces your site’s carbon footprint and improves user experience by reducing its image data transfer and improving image load times.
 * Version:           1.1.2
 * Author:            Seenthis
 * Author URI:        https://www.seenthis.co
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       greenweb
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 */
define( 'GREENWEB_VERSION', greenweb_globals\version );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-greenweb-activator.php
 */
function activate_greenweb() {
	global $greenweb_globals;
	require_once $greenweb_globals->pluginDir . 'includes/class-greenweb-activator.php';
	Greenweb_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-greenweb-deactivator.php
 */

function deactivate_greenweb() {
	global $greenweb_globals;
	require_once $greenweb_globals->pluginDir . 'includes/class-greenweb-deactivator.php';
	Greenweb_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_greenweb' );
register_deactivation_hook( __FILE__, 'deactivate_greenweb' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require $greenweb_globals->pluginDir . 'includes/class-greenweb.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.1.0
 */

$latest = $greenweb_globals->latestUrl;
$optiUrl = $greenweb_globals->optiUrl;
$seenthis = $greenweb_globals->seenthis;
$replace = $greenweb_globals->replace;
$pluginName = greenweb_globals\pluginName;


function run_greenweb() {
	
	$plugin = new Greenweb();
	$plugin->run();
	
	function  hook_javascript() { 
		global $latest; 
		?>
		<script src=<?php echo esc_url($latest)?>></script>

		<script>
			window.onInitStreaming = function (active) {
			window.dataLayer = window.dataLayer || [];
			window.dataLayer.push({
				event: $pluginName,
				loaded: active ? 'active-v-2' : 'no-active-v-2'
			});
		};
	</script>

	<?php }

	add_action('wp_head', 'hook_javascript');

	/**
	 * Set links for greenweb at plugins.
	 * @return Url to plugin settings
	 */
	function getSettingsUrl(){
		return admin_url() . 'admin.php?page='. greenweb_globals\rootFolder .'/admin/partials/admin-display.php';
	}

	/**
	 * Set links for greenweb at plugins.
	 * @param $links
	 * @return mixed
	 */
	function addSettingsLink($links) {
		$links[] = '<a href="' . getSettingsUrl() . '">Settings</a>';
		
		return $links;
	}

	add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'addSettingsLink');

	/**
	 * When redirect to adminpage when activated
	 * @param $plugin
	 */
	function redirectOnActivate($plugin) {
		if( $plugin === plugin_basename(__FILE__) ) {
			exit( wp_redirect( getSettingsUrl() ) );
		}
	}

	add_action( 'activated_plugin', 'redirectOnActivate' );


	/**
	 * Function to change greenweb option from ajax
	 * @param 
	 */
	function update_greenweb_option_ajax(){

		$val = sanitize_text_field($_POST["option"]);

		if (!preg_match('/[^A-Za-z0-9]/', $val)){
			update_option(greenweb_globals\option, $val);
			return http_response_code(200);
		} else return http_response_code(403);
		die(); 
	}

	add_action( 'wp_ajax_' . 'greenweb_option_ajax', 'update_greenweb_option_ajax' );
	add_action( 'wp_ajax_nopriv_' . 'greenweb_option_ajax', 'update_greenweb_option_ajax' );

	global $greenweb_globals;
	global $latest;


	// Check if prefix is ok othervise dont load plugin functions
	if (!$greenweb_globals->prefix || $greenweb_globals->prefix === '403') {
		return;
	}
	$response = wp_remote_get($latest);
	$http_code = wp_remote_retrieve_response_code($response);
	if ($http_code !== 200) {
		return;
	}

	/**
	 * Change src for greenweb.
	 * @param $content
	 * @return mixed
	 */
	function greenweb($content) {
		$content  = mb_convert_encoding($content, 'HTML-ENTITIES', 'UTF-8');
		if ($content) {
			$document = new \DOMDocument();	
			libxml_use_internal_errors(true);
			$document->loadHTML(utf8_decode($content));

			global $optiUrl;
			$images = $document->getElementsByTagName('img');

			foreach ($images as $img) {	   
				$srcset = $img->getAttribute('srcset');
				$src = $img->getAttribute('src');
				$style = $img->getAttribute('style');

				if(!strpos($style, 'background-image:')) {
					$img->setAttribute('src', $optiUrl . $src);
					
					if ($srcset) {
						global $replace;
						$img->setAttribute('srcset', strtr($srcset, $replace));
					};
				}
			}	
	
			return $document->saveHTML();
		}
	}

	add_filter('the_content', 'greenweb');

	/**
	 * Change srcset for greenweb.'
	 * @param $attributes
	 * @return mixed
	 */
	function greenwebAlterSrcset($attributes){
		global $seenthis;
		if  ($attributes['srcset'] && !strpos($attributes['srcset'], $seenthis)) {
			global $replace;
			$attributes['srcset'] = strtr($attributes['srcset'],$replace);
		}
		return $attributes;
	}

	add_filter( 'wp_get_attachment_image_attributes', 'greenwebAlterSrcset' );

	/**
	 * Change src for greenweb.
	 * @param $attributes
	 * @return mixed
	 */
	function greenwebAlterSrc($attributes) {
		global $seenthis;
		if(!strpos($attributes[0], $seenthis)) {
			global $optiUrl;
			$attributes[0] = $optiUrl . $attributes[0];		
		}
		return $attributes;
	}

	add_filter( 'wp_get_attachment_image_src', 'greenwebAlterSrc');

	// Removes loading lazy
	add_filter( 'wp_lazy_loading_enabled', '__return_false' );	

	// Deactivate plugin and change prefix in db
	function greenweb_check_prefix() {
		global $greenweb_globals;
		global $latest;
		if (!$greenweb_globals->prefix || $greenweb_globals->prefix === '403') {
			return;
		}
		$response = wp_remote_get($latest);
		$http_code = wp_remote_retrieve_response_code($response);

		if ($http_code !== 200) {
			require_once(ABSPATH . 'wp-admin/includes/plugin.php');
			update_option($greenweb_globals->option, $http_code);
			deactivate_plugins( 'greenweb/greenweb.php' );
			wp_clear_scheduled_hook( 'seenthis_check_prefix' );
			register_deactivation_hook( __FILE__, 'seenthis_check_prefix' );
		}
	}

	//Cron	
	
	add_action( 'seenthis_check_prefix', 'greenweb_check_prefix' );
	if ( ! wp_next_scheduled( 'seenthis_check_prefix' ) ){
		wp_schedule_event( time(), 'daily', 'seenthis_check_prefix' );
	}
}

run_greenweb();